************************
***Preparation of March 1975 CPS-Data for analysis 
**************************************************
quietly {
* This do-file contains the data pre-processing for the 1974 analysis, including import 
* of the original .csv-files, data manipulation and sample definitions.
*
*March 1975 ASEC-CPS data refers to income data of 1974
*
* database: csv1975.csv
*
* output: data1974.dta
*
********************************************************************************


*import original data
import delimited "${raw}cps1975.csv", clear

 
*rename the identifying variable
rename serial hhid
label var hhid "Household identifier"


*the CPS provides an analytical weight, for the income distribution estimation 
*frequency weights are required
g double fwt = round(asecwt*(1/.01))

label var asecwt "Analytical weight"
label var fwt "Frequency weight"
label var year "Year"


*declare survey design (STATA treats pweights as aweights) to be able to calculate
*descriptives correctly
svyset hhid [pweight=asecwt]


*****************************
***Calculate personal incomes

*gross income = wage and salary income + self-employed income
*self-employed income = non-farm business income + farm income
*non-farm business income and farm income are reported as net income


*declare missings
mvdecode incwage incbus incfar, mv(9999998,9999999,99999999)


*as non-farm business income and farm income are net incomes they can be negative
*the taxes and transfers analysed do not account for losses, hence, negative incomes
*count as zero income 
foreach name in incbus incfarm{
replace `name' = 0 if `name' <0 & `name'!=.
}

***generate personal gross income
gen pinc = incwage + incbus + incfarm
label var pinc "Personal earned income"


***Investment (capital) income

*declare missings
mvdecode incidr, mv(99999)

*reported investment income is net income, negative incomes count as zero income
gen iinc = incidr if incidr!=. & incidr>0
replace iinc = 0 if incidr<0
label var iinc "Personal investment income"


**********************
***Working age dummy

gen idwage2560 = (age >= 25 & age <= 60 )
label var idwage2560 "Working age (> 24, <= 60) dummy"



*******************************
***Identify type of filing unit

*in this analysis childless singles and single parents are taken into account
*in the following, the type is determined following the tax regulations
*there are 3 elements: persons counting as dependents, exemptions

/*RELATE Relationship to household head
0101		Head/householder
0201		Spouse
0301		Child
0501		Parent
0901		Grandchild (only 1975)
1001		Other relatives, n.s.
1260		Other nonrelatives


MARST Marital status
1 Married, spouse present
2 Married, spouse absent
3 Separated
4 Divorced
5 Widowed
6 Never married/single
9 NIU (only 1975)

EMPSTAT		Employment status
00		NIU
01		Armed Forces
10		At work
12		Has job, not at work last week
21		Unemployed, experienced worker
22		Unemployed, new worker
31		NILF, housework
32		NILF, unable to work
33		NILF, school
34		NILF, other
36		NILF, retired
*/


*tax definition of a dependent person
gen dep = (relate == 301  | relate == 901)
label var dep "Person is a dependent"

*tax definition of person that can be claimed as exemption
gen ex = .
label var ex "Person can be claimed as exemption"
replace ex = 1 if dep == 1 & marst != 1 & marst!= 2 & age <= 19 
replace ex = 1 if dep == 1 & marst != 1 & marst!= 2 & pinc <= 650 

*number of exemptions per household
bys hhid: egen nctax = total(ex)
label var nctax "Number of exemptions for filing taxes"

*tax definition: childless singles/single parents
gen fu = .
label var fu "Type of head of household"

replace fu = 1 if relate == 101 & marst != 1 & marst!=2 & nctax == 0
replace fu = 2 if relate == 101 & marst != 1 & marst!=2 & nctax >= 1


label define fus 1 "Unmarried individual" 2 "Head of household" 
label value fu fus 



********************
***Identify children

*below age 19
gen c = (age < 19 & relate == 0301)
label var c "Person is a child < 19"

*number of children per household
bys hhid: egen nc = total(c)
label var nc "Number of children < 19"


*children eligible for AFDC: below age 15 or below age 18 and in education
gen child = .
label var child "Person is a child in the definition of AFDC"
replace child = 1 if dep == 1 & age <= 15
replace child = 1 if dep == 1 & age > 15 & age <= 18 & empstat == 33

*AFDC children per household
bys hhid: egen ncafdc = total(child)
label var ncafdc "Number of children eligible for AFDC"



************************************************************
***Identify households containing only singles, potentially with dependent children

*number of persons living in household
bys hhid: egen nper = count(pernum)
label var nper "Number of persons in household"

*identify single households
gen hht = .
replace hht = 1 if fu == 1 & nper == 1
replace hht = 1 if fu == 2 & nper == (1+ncafdc)
replace hht = 2 if fu == 1 & nper > 1
replace hht = 2 if fu == 2 & nper > (1+ncafdc)


*check whether each household has only one type assigned
bys hhid: egen check = count(hht)
count if check != 0 & check != 1

if r(N) == 0 {
	*create variable indicating single households
	bys hhid: egen idsinglef = total(hht),m
	drop hht check
	}
else {
	noi di "error: some households have assigned more than 1 value for household type"
	}

*label variable (values)
label var idsinglef "Family category"
label define idsinglefs 1 "Single family" 2 "Extended single family"
label values idsinglef idsinglefs


******************************
***Calculate household incomes

*Household gross income of all members
bys hhid: egen hhinc = total(pinc), m
label var hhinc "Earned income"
	

*Household investment income
gen invinccf = .
replace invinccf = iinc if fu!=.
replace invinccf = iinc if c == 1
replace invinccf = iinc if relate == 201
bys hhid: egen hhinvinc = total(invinccf)
label var hhinvinc "Investment income"


***Identify zero income households
gen idzero = (hhinc == 0)
label var idzero "Zero income dummy"

label define idzeros 0 "Positive income" 1 "Zero income"
label values idzero idzeros


***Identify households with income in EITC range (0,8000)
gen ideitc = (hhinc > 0 & hhinc < 8000)
label var ideitc "Dummy: Earned income in EITC range"

label define ideitcs 0 "Not EITC range" 1 "EITC range"
label values ideitc ideitcs




*****************
***Define benchmark sample

***Sample restrictions

gen sample = .
label var sample "BM sample: age 25-60, childless single, no children/single parent, AFDC children"


***Single parents
replace sample = 2 if fu==2 & nc > 0 & ncafdc > 0 & idwage2560==1 & idsinglef==1

***Childless singles
replace sample = 1 if fu==1 & nc == 0 & ncafdc==0 & idwage2560==1 & idsinglef==1

***Value labels
label define single 1 "Childless single" 2 "Single parent" 
label value sample single 


***********************************
****Drop variables and observations
*Only keep observations with childless singles and single parents (one observation - one household)
keep if sample !=. 

*Only keep variables needed for subsequent analysis
keep year hhid age hhinc hhinvinc id* asecwt fwt sample 

order year asecwt fwt sample age hhinc id*

sort hhinc
}

************
***save data for further analysis
save "${data}data1974.dta", replace
