**************************************************
***Calculation of revenue function y->R(y) based on 1974 US tax system for single parents
**************************************************

quietly {
*This do-file estimates the income distribution for single parents based on 1975 ASEC-CPS data, 
*adds information on the effective tax-transfer rates, 
*and calculates the revenue function for the benchmark case 
*and several different values of the labor supply elasticities.
*
* database: - data1974.dta 
*			- bracket1974-2 (kink points in 1974 tax-transfer schedule for single parents w 2 children)
* 
* programs: - Tax1974-2.do (effective tax-transfer rates for single parents w 2 children, 1974)
* 			- rfunc.ado (calculates revenue function for different scenarios)
*
* output: 	- R1974-sp.dta
*			- R1974-sp.csv
*
* figures:  - Fig4a_TaxRates_SingleParents
*			- Fig5_RevenueFunction_SingleParents_BM
*			- Fig6_RevenueFunction_SingleParents_RobustExtensive
*			- FigS1a_IncomeDistrPDF_SingleParents
*			- FigS1b_IncomeDistrCDF_SingleParents
*			- FigS3_RevenueFunction_SingleParents_RobustIntensive
*			- FigS5_RevenueFunction_SingleParents_RobustIncomeEffects
********************************************************************************


**************
***Set up Data

local dist 25

* load data and set range of observations and distance
use "${data}data1974.dta", clear
sum hhinc if sample==2
local maxi = round(r(max))
local o = round((`maxi' / `dist') + 1)

*gen variable bracket, set one datapoint every 25 USD from 0 to highest observed income 
*datapoints are later used for kernel estimation of income distribution
clear 
set obs `o'
gen bracket = .
gen id = _n
qui {
local n = 1
forvalues num = 0 (`dist') `maxi' {
replace bracket = `num' if id==`n'
local n = `n' + 1
}

***add further datapoints around kink points in tax-transfer schedule
file open myfile using "${tax}bracket1974-2.txt", read
file read myfile bra
file close myfile

foreach num of numlist `bra'  {
local new = _N + 1
set obs `new'
replace bracket = `num' if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 5 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 5 if bracket==.


local new = _N + 1
set obs `new'
replace bracket = `num' + 50 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 50 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 55 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 55 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 45 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 45 if bracket==.
local new = _N + 1
set obs `new'
local new = _N + 1
set obs `new'
replace bracket = `num' + 250 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 250 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 255 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 255 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 245 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 245 if bracket==.
local new = _N + 1
set obs `new'

drop if bracket<0


}

*Add further datapoints around income levels that become relevant for optimal reform later 
local nums = "1244 1245 1246 1247 1248 10248 10249 10250 10251 10252"

foreach num in `nums' {
local new = _N + 1
set obs `new'
replace bracket = `num' if bracket == . 
}
}

*sort observations, drop duplicates and datapoints above maximum income 
sort bracket
duplicates drop bracket, force

drop if bracket>`maxi'

*Combine datapoints with CPS data
append using "${data}data1974.dta"
sort hhinc


*****************************************
***Estimate income distribution**********

***Kernel density estimation with Gaussian kernel
***bandwidth chosen sollowing Silverman's rule: 997.8349**

*Estimate gaussian kernel density
kdensity hhinc if idzero==0 & sample==2 [fweight=fwt], at(bracket) kernel(gaussian) bwidth(997.8349) generate(kdxs kdds) nograph

*only keep kernel densities
keep if kdxs != . 
sort kdxs
rename kdxs y


*share zero income HHs (see CPS2_desc_Replication)
scalar s1974 = `=.3090586'


*pdf excl. zero incomes
*correct for "probability leakage" st probability of kernel density estimates amounts to 1
integ kdds y, trapezoid
gen fykernelz = 1/r(integral)*kdds
label var fykernelz "PDF, kernel estimate, excluding zero income HHs"

*pdf incl. zero incomes
gen fykernel = (1-s1974 )*fykernelz
label var fykernel "PDF income distr single parents (BM)"

replace fykernel = . if y == 0

*cdf including zero incomes
integ fykernel y, generate(i_S) trapezoid
gen Fykernel = s1974  + i_S
label var Fykernel "CDF income distr single parents (BM)"

qui: replace Fykernel = s1974  if y == 0

drop kdds i_S

***Plot pdf and cdf of estimated income distribution (see Table S.1 in Supp Material) 
twoway (scatter Fykernel y if y >0 & y < 35000)
graph save "${graphs}FigS1b_IncomeDistrCDF_SingleParents.gph", replace

twoway (scatter fykernel y if y >0 & y < 35000) 
graph save "${graphs}FigS1a_IncomeDistrPDF_SingleParents.gph", replace

****************
***generate T(y)

*define effective marginal tax rates and effective participation tax rates
qui: do "${tax}Tax1974-2.do"

***Plot effective marginal/participation tax rates (see Figure 4a) 
twoway (scatter Tprime y if y >0 & y < 18000)  (scatter TPprime y if y >0 & y < 18000)
graph save "${graphs}Fig4a_TaxRates_SingleParents.gph", replace



***********************
***Calculate revenue functions based on equation (11) in subsection 2.5 
***and equations (D.1) and (D.2) in the Supplementary Material (for cases w. income effects)

*0. benchmark case
*1. Robustness w.r.t. intensive-margin elasticity epsilon
*2. Robustness w.r.t. participation elasticity pi
*3. Robustness w.r.t. income effects at both margins

gen epsi = .
gen pi = .
label var epsi "Intensive-margin elasticity"
label var pi "Participation elasticity"



***************
***0. Set parameters for benchmark scenario
replace epsi = 0.33
gen bpi = 0.67 - 0.27 * (y/50000)^(1/2) if y <= 50000
replace bpi = 0.4 if y > 50000
label var bpi "Participation elasticity (BM)"

replace pi = bpi

***Calculate revenue function for benchmark scenario
rfunc BM

***Plot revenue function for single parents, BM scenario (Figure 5 in main text)
twoway (scatter R_BM y if y >0 & y < 15000)
graph save "${graphs}Fig5_RevenueFunction_SingleParents_BM.gph", replace


*********************
***1. Sensitivity analysis: different intensive-margin elasticities (epsilon)


local n = 0

*Set different parameter values for epsilon and calculate revenue functions
*epsilon = 0, 0.1, 0.5

foreach num in 0 1 5 {

*Set different parameter values
replace epsi = 0.`num'
local n = `n'+1

***Calculate revenue function for different cases
rfunc 1`n'

}

***Plot revenue functions for different values of epsilon (Figure S.3 in Supp Material)
twoway (scatter R_BM y if y >0 & y< 15000) (scatter R_11 y if y >0 & y< 15000) (scatter R_12 y if y >0 & y< 15000) (scatter R_13 y if y >0 & y< 15000)
graph save "${graphs}FigS3_RevenueFunction_SingleParents_RobustIntensive.gph", replace


*********************
***2. Sensitivity analysis: different participation elasticities (pi)

***Set different parameter values for pi and calculate revenue functions

***2.1 No reponses at extensive margin, pi=0
replace epsi = 0.33
replace pi = 0

***Calculate revenue function for case pi = 0
rfunc 21


***2.2 Participation elasticity pi falls from 1 to 0.75, average value of 0.9
replace pi = 1 - 0.25 * (y/50000)^(1/2) if y <= 50000
replace pi = 0.75 if y > 50000

***Calculate revenue function for case with average pi = 0.9
rfunc 22


***Plot revenue functions for different values of pi (Figure 6 in main text)
twoway (scatter R_BM y if y >0 & y< 15000) (scatter R_21 y if y >0 & y< 15000) (scatter R_22 y if y >0 & y< 15000) 
graph save "${graphs}Fig6_RevenueFunction_SingleParents_RobustExtensive.gph", replace


********************************
***3. Sensitivity analysis:  Allow for income effects

replace epsi = 0.33
replace pi = bpi

***Set parameter values for two scenarios with income effects and calculate revenue functions

***Case 1: nu = -8 × 10^-6, eta = -0.08, corresponding to MPE = -0.1 
scalar nu = -8*10^(-6)
scalar eta = -0.08

***Calculate revenue function for case with MPE = -0.1
rfunc 31


***Case 2: nu = -2.4 × 10^-5, eta = -0.24, corresponding to MPE = -0.4
scalar nu = -2.4*10^(-5)
scalar eta = -0.24

***Calculate revenue function for case with MPE = -0.4
rfunc 32


***Plot revenue functions with small and large income effects (Figure S.5 in Supp Material)
twoway (scatter R_BM y if y >0 & y< 15000)  (scatter R_31 y if y >0 & y< 15000) (scatter R_32 y if y >0 & y< 15000) 
graph save "${graphs}FigS5_RevenueFunction_SingleParents_RobustIncomeEffects.gph", replace


******************
***Save and Export

*drop unused variables
keep y fykernel Fykernel Tprime TPprime R_BM R_11 R_12 R_13 R_21 R_22 R_31 R_32 
}

*save data
save "${data}R1974-sp.dta", replace


*Export data to csv (for figures produced with tex-package tikz) 
export delimited using "${latex}R1974-sp.csv", replace

