**********************************************************************************************
***Identifying the optimal reform direction for 1974 US tax-transfer system*****************
**********************************************************************************************

quietly {
***Revenue function for 1974 US tax-transfer system satisfies Assumption 1 in Online Appendix*
***Definition of optimal reform direction given in Proposition B.1 in Online Appendix*********

***Revenue function is discontinuously increasing at y = 5748*********************************
***Optimal reform involves two brackets left and right of discontinuity***********************
***Endpoints of brackets ys = 5748 - delta and yt = 5748 + delta>ys such that R(ys)=R(yt)*****
**********************************************************************************************
*
* database: - R1974-sp.dta 
*
* Auxiliary figures: - FigZ1_OptimalReform_SingleParents_1
* 					 - FigZ2_OptimalReform_SingleParents_2
* 					 - FigZ3_OptimalReform_SingleParents_3
**********************************************************************************************


*Load data 
use "${data}R1974-sp.dta", clear

*Compute integral below revenue function
integ R_BM y, trapezoid gen(intRsp)

***Define income level with discontinuity*****************************************************
local ym = 5748

***Look for interval length delta>0 such hat R(5748-delta) = R(5748+delta)********************
gen delta = .
replace delta =  `ym' - y
replace delta = abs(delta)
replace delta = . if delta >= `ym'
gen Rdelta1 = R_BM if y<`ym'
gen Rdelta2 = R_BM if y>`ym' & y<=2*`ym'

*labels for Rdelta1 and Rdelta2
label var Rdelta1 "R(y_m - delta) for single parents"
label var Rdelta2 "R(y_m + delta) for single parents"


***Solve graphically for intersection of Rdelta1 and Rdelta2
twoway (scatter Rdelta1 delta)  (scatter Rdelta2 delta)
graph save "${graphs}FigZ1_OptimalReform_SingleParents_1.gph", replace

twoway (scatter Rdelta1 delta if delta>4450 & delta<4550)  (scatter Rdelta2 delta if delta>4450 & delta<4550)
graph save "${graphs}FigZ2_OptimalReform_SingleParents_2.gph", replace

twoway (scatter Rdelta1 delta if delta>4500 & delta<4505)  (scatter Rdelta2 delta if delta>4500 & delta<4505)
graph save "${graphs}FigZ3_OptimalReform_SingleParents_3.gph", replace

***Intersection of Rdelta1 and Rdelta2 at delta = 4502***
***Hence, by Proposition B.1: Optimal interval length delta is given by 4502, gives values of endpoints y_s and y_t**
local ys = `ym' - 4502
local yt = `ym' + 4502

*locals for values
*Evaluate integral for optimal phase-in range (1246, 5748)
sum intRsp if y == `ys'
local ze: di %9.3f r(mean)
sum intRsp if y==`ym'
local Z1s: di %9.3f r(mean) - `ze'
di `Z1s'

*Evaluate integral for optimal phase-out range (5748, 10250)
sum intRsp if y==`yt'
local Z2s: di %9.3f r(mean) - (`Z1s' + `ze')
di `Z2s' 

*Calculate marginal revenue gain of optimal reform, difference of both integrals
local Zs: di %9.3f -`Z1s' + `Z2s'
di `Zs'


**Drop auxiliary variables
drop intRsp delta Rdelta1 Rdelta2
}

*** Results on optimal reform for single parents
*** (as reported in Subsection 3.3 and in Table S.5 in Supp Material)**

**Optimal endpoints of brackets 
di `ys'
di `ym'
di `yt'

**Marginal revenue gain from optimal reform
di `Zs'

