**************************************************
***Calculation of revenue function y->R(y) based on 1974 US tax system for single parents
**************************************************
quietly {
*This do-file estimates the income distribution for childless singles based on 1975 ASEC-CPS data, 
*adds information on the effective tax-transfer rates, 
*calculates the revenue function for the benchmark case 
*the marginal revenue effect of the 1975 EITC reform,
*and the optimal reform direction given the 1974 tax-transfer system for childless singles.
*
* database: - data1974.dta 
*			- bracket1974-s (kink points in 1974 tax-transfer schedule for childless singles)
* 
* programs: - Tax1974-s.do (effective tax-transfer rates for single parents w 2 children, 1974)
* 			- rfunc.ado (calculates revenue function for different scenarios)
*
* output: 	- R1974-cs.dta
*			- R1974-cs.csv
*
* figures:  - Fig4b_TaxRates_Childless
*			- Fig5_RevenueFunction_Childless_BM
*			- FigS1a_IncomeDistrPDF_Childless
*			- FigS1b_IncomeDistrCDF_Childless
* 			- FigZ4_OptimalReform_Childless_1
* 			- FigZ5_OptimalReform_Childless_2
* 			- FigZ6_OptimalReform_Childless_3
* 			- FigZ7_OptimalReform_Childless_4
********************************************************************************


**************
***Set up Data

local dist 25

*load data and set range of observations and distance
use "${data}data1974.dta", clear
sum hhinc if sample==1
local maxi = round(r(max))
local o = round((`maxi' / `dist') + 1)

*gen variable bracket, set one datapoint every 25 USD from 0 to highest observed income 
*datapoints are later used for kernel estimation of income distribution
clear 
set obs `o'
gen bracket = .
gen id = _n
qui {
local n = 1
forvalues num = 0 (`dist') `maxi' {
replace bracket = `num' if id==`n'
local n = `n' + 1
}
}

*add further datapoints around kink points in tax-transfer schedule
file open myfile using "${tax}bracket1974-s.txt", read
file read myfile bra
file close myfile

qui {
foreach num of numlist `bra'  {
local new = _N + 1
set obs `new'
replace bracket = `num' if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 5 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 5 if bracket==.

local new = _N + 1
set obs `new'
replace bracket = `num' + 50 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 50 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 55 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 55 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 45 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 45 if bracket==.
local new = _N + 1
set obs `new'
local new = _N + 1
set obs `new'
replace bracket = `num' + 250 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 250 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 255 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 255 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' - 245 if bracket==.
local new = _N + 1
set obs `new'
replace bracket = `num' + 245 if bracket==.
local new = _N + 1
set obs `new'

drop if bracket<0
}

*Add further datapoints around income levels that become relevant for optimal reform later 
local nums = "2077 2078 2079 2080 2081 2082 2346 2347 2348 2349 2350 2351 8577 8578 8579 8580 8581 8752 8753 8754 8755 8756 "
foreach num in `nums' {
local new = _N + 1
set obs `new'
replace bracket = `num' if bracket == . 
}
}

*sort observations, drop duplicates and datapoints above maximum income
sort bracket
duplicates drop bracket, force

drop if bracket>`maxi'


*Combine datapoints with CPS data
append using "${data}data1974.dta"
sort hhinc



*****************************************
***Estimate income distribution**********

***Kernel density estimation with Gaussian kernel
***bandwidth chosen sollowing Silverman's rule: 927.3891**


*Estimate gaussian kernel density
kdensity hhinc if idzero==0 & sample==1 [fweight=fwt], at(bracket) kernel(gaussian) bwidth(927.3891) generate(kdxs kdds) nograph


*only keep kernel densities
keep if kdxs != . 
sort kdxs

rename kdxs y


*share zero income HHs (see CPS2_desc_Replication)
scalar ssingle1974 = `=.1482036'

*pdf excl. zero incomes
*correct for "probability leakage" st probability of kernel density estimates amounts to 1
integ kdds y
gen fykernelz = 1/r(integral)*kdds
label var fykernelz "PDF, kernel estimate, excluding zero income HHs"

*pdf incl. zero incomes
gen fykernel = (1-ssingle1974)*fykernelz

*cdf including zero incomes
integ fykernel y, generate(i_S) trapezoid
gen Fykernel = ssingle1974 + i_S

replace fykernel = . if y == 0
replace Fykernel = ssingle1974 if y == 0

*labels
label var fykernel "PDF income distr childless singles (BM)"
label var Fykernel "CDF income distr childless singles (BM)"


drop kdds i_S

***Plot pdf and cdf of estimated income distribution (see Table S.1 in Supp Material) 
twoway (scatter Fykernel y if y >0 & y < 35000)
graph save "${graphs}FigS1b_IncomeDistrCDF_Childless.gph", replace

twoway (scatter fykernel y if y >0 & y < 35000) 
graph save "${graphs}FigS1a_IncomeDistrPDF_Childless.gph", replace



****************
***generate T(y)

*define effective marginal tax rates and effective participation tax rates
qui: do "${tax}Tax1974-s.do"

***Plot effective marginal/participation tax rates (see Table 4b) 
twoway (scatter Tprime y if y >0 & y < 18000) (scatter TPprime y if y >0 & y < 18000)
graph save "${graphs}Fig4b_TaxRates_Childless.gph", replace


***********************
***Calculate revenue functions based on equation (11) in subsection 2.5 


*Define parameters for labor supply elasticities

gen epsi = .
gen pi = .

*********************
***Set parameters for benchmark scenario
replace epsi = 0.33
replace pi = 0.4 - 0.25 * (y/50000)^(1/2) if y <= 50000
replace pi = 0.15 if y > 50000

***Calculate revenue function for benchmark scenario
rfunc CS

***Plot revenue function for childless singles, BM scenario (Figure 5 in main text)
twoway (scatter R_CS y if y >0 & y < 15000)
graph save "${graphs}Fig5_RevenueFunction_Childless_BM.gph", replace
}

**********************************************************************************************
***Computing the marginal revenue effect of the 1975 reform introducing the EITC***************
**********************************************************************************************

quietly{
***1975 EITC reform: marginal taxes reduced for y in (0,4000), increased on y in (4000,8000)**
***Formula for computing Gateaux differential in direction of 1975 EITC reform: equation (12)***
**********************************************************************************************


*Compute integral below revenue function
integ R_CS y, trapezoid gen(intRcs)

*Evaluate integral for interval (0,4000)
sum intRcs if y==4000
local S1: di %9.3f r(mean)

*Evaluate integral for interval (4000,8000)
sum intRcs if y==8000
local S2: di %9.3f r(mean) - `S1'

*Calculate marginal revenue gain of EITC reform
local S: di %9.3f -`S1' + `S2'
}
***Display marginal revenue gain of EITC reform for childless singles***
***(not reported in paper)***
di `S'


**********************************************************************************************
***Identifying the optimal reform direction for 1974 US tax-transfer system, childless singles
**********************************************************************************************

quietly {
***Revenue function for 1974 US tax-transfer system satisfies adjusted version of Assumption 1 in Online Appendix*
***Definition of optimal reform direction given in Proposition B.1 in Online Appendix*********

***Revenue function is discontinuously increasing at y = 2314 and at y = 3020*********************************
***Optimal reform involves, for each discontinuity, two brackets left and right of discontinuity***********************
***Endpoints of brackets ys = 3020 (2314) - delta and yt = 3020 (2314) + delta>ys such that R(ys)=R(yt)*****

 ****************************
***Define first income level with discontinuity
local ym1 = 2214

***Look for interval length delta>0 such hat R(2214-delta) = R(2214+delta)********************
gen delta2 = .
replace delta2 =  `ym1' - y
replace delta2 = abs(delta2)
replace delta2 = . if delta2 >= `ym1'
gen Rdelta1 = R_CS if y<`ym1'
gen Rdelta2 = R_CS if y>`ym1' & y<=2*`ym1'

*labels for Rdelta1 and Rdelta2
label var Rdelta1 "R(y_m1 - delta) for childless"
label var Rdelta2 "R(y_m1 + delta) for childless"

***Solve graphically for intersection of Rdelta1 and Rdelta2
twoway (scatter Rdelta1 delta2)  (scatter Rdelta2 delta2)
graph save "${graphs}FigZ4_OptimalReform_Childless_1.gph", replace
twoway (scatter Rdelta1 delta2 if delta2> 130 & delta2 < 140)  (scatter Rdelta2 delta2 if delta2> 130 & delta2 < 140)
graph save "${graphs}FigZ5_OptimalReform_Childless_2.gph", replace

***Interval length delta is given by 134, gives values of endpoints y_s and y_t**
local ys1 = `ym1' - 134
local yt1 = `ym1' + 134
di `ys1'
di `yt1'

*locals for values
*Evaluate integral for optimal phase-in range 
sum intRcs if y== `ys1'
local S1e: di %9.3f r(mean)
sum intRcs if y==`ym1'
local S1a: di %9.3f r(mean) - `S1e'
di `S1a'

*Evaluate integral for optimal phase-out range 
sum intRcs if y==`yt1'
local S1b: di %9.3f r(mean) - (`S1a' + `S1e')
di `S1b' 

*Calculate marginal revenue gain of optimal reform, difference of both integrals
local S1: di %9.3f -`S1a' + `S1b'
di `S1'


****************************
***Define income level with discontinuity
local ym2 = 8667

***Look for interval length delta>0 such hat R(8667-delta) = R(8667+delta)********************
gen delta = .
replace delta =  `ym2' - y
replace delta = abs(delta)
replace delta = . if delta >= `ym2'
gen Rdelta3 = R_CS if y<`ym2'
gen Rdelta4 = R_CS if y>`ym2' & y<=2*`ym2'

*labels for Rdelta3 and Rdelta4
label var Rdelta3 "R(y_m2 - delta) for childless"
label var Rdelta4 "R(y_m2 + delta) for childless"


***Solve graphically for intersection of Rdelta3 and Rdelta4
twoway (scatter Rdelta3 delta)  (scatter Rdelta4 delta)
graph save "${graphs}FigZ6_OptimalReform_Childless_3.gph", replace

twoway (scatter Rdelta3 delta if delta >85 & delta<90)  (scatter Rdelta4 delta if delta >85 & delta<90)
graph save "${graphs}FigZ7_OptimalReform_Childless_4.gph", replace


***Interval length delta is given by 87, gives values of endpoints y_s and y_t**
local ys2 = `ym2' - 87
local yt2 = `ym2' + 87
di `ys2'
di `yt2'

*locals for values
*Evaluate integral for optimal phase-in range 
sum intRcs if y== `ys2'
local S2e: di %9.3f r(mean)
sum intRcs if y==`ym2'
local S2a: di %9.3f r(mean) - `S2e'
di `S2a'

*Evaluate integral for optimal phase-out range 
sum intRcs if y==`yt2'
local S2b: di %9.3f r(mean) - (`S2a' + `S2e')
di `S2b' 

*Calculate marginal revenue gain of optimal reform, difference of both integrals
local S2: di %9.3f -`S2a' + `S2b'
di `S2'


*Sum up marginal revenue gain from reforms around both discontinuities
local St: di %9.3f + `S1' + `S2'


}

*********************************************************************
*** Results on optimal reform for childless singles
***(marginal revenue gain reported in Subsection 3.3, p. 35)**

**Optimal first phase-in range 
di `ys1'
di `ym1'

**Optimal first phase-out range 
di `ym1'
di `yt1'


**Optimal second phase-in range 
di `ys2'
di `ym2'

**Optimal second phase-out range 
di `ym2'
di `yt2'

**Marginal revenue gain from optimal reform
di `St'



******************
***Save and Export

*select variables
keep y fykernel Fykernel Tprime TPprime R_CS



*save data
save "${data}R1974-cs.dta", replace

*Export data to csv (for figures produced with tex-package tikz)
export delimited using "${latex}R1974-cs.csv", replace

