*program drop rfunc

program rfunc

***description
* this programe calculates the revenue function R(y), 
* based on equation (11) in subsection 2.5 (without income effects)
* and equations (D.1) and (D.2) in the Supp Material (with income effects)
*********************************************************
* Equation (11): R(y) consists of three terms g1(y), g2(y), and g3(y).
* Equation (D.1): R(y) also contains term g4(y) in the numerator and 
* multiplier (1-M_0)^{-1}
*********************************************************
* Program generates terms ga, g2, g3 
* (and g4, M_0 for case with income effects)
* then computes and stores function R(y) 1974 tax rates
*********************************************************
* Inputs: - pdf and cdf of income distribution,
*         - marginal/participation tax rates, and
*         - labor supply elasticities epsilon, pi, gamma, nu 

* Define arguments of program: 
* - suffix: suffix of generated variables


args suf

tempvar gtilde3 intg3 gtilde4 intg4 etaterm nuterm


*Save lowest value of epsi
sum epsi 
local epsil: di %6.2f r(min)
*Save lowest and highest value of pi
sum pi 
local pil: di %6.2f r(min)
local pih: di %6.2f r(max)
  
***Generate first term: g1(y) = 1- F_y(y)
capture confirm variable g1
if _rc {
gen g1 = 1 - Fykernel
label var g1 "Term g1 = 1 - Fy"
}

capture confirm existence `suf'
        if _rc {
		local suff `'
		}
	
else {
		local suff "_`suf'"
}


***Generate second term: g2(y) = epsilon(y) y f_y(y) T'_0(y) [1- T'_0(y)]^{-1}
gen g2`suff' = (epsi)*y*(fykernel)*(Tprime/(1-Tprime))
label var g2`suff' "Term g2 "


***Generate third term: g3(y) = int_y^\infty f_y(y') pi(y') T_0(y') * [1- T_0(y')]^{-1} d y'
*Define term within integral: gtilde3
gen `gtilde3' = (fykernel)*pi*(TP/(y-TP))

*Evaluate integral over gtilde3 from 0 to infinity
integ `gtilde3' y, gen(`intg3') trapezoid

*Evaluate integral over gtilde3 from y to infinity
gen g3`suff' = r(integral)  - `intg3'

label var g3`suff' "Term g3"


***Additional terms for version with income effects
if "`suf'" >= "31" & "`suf'" <= "39" | "`suf'" == "`'" {


***Generate fourth term: g4(y) = int_0^{\bar y} f_y(y') eta(y') T'_0(y') d y'

*Define term within integral: gtilde4
gen `gtilde4'  = fykernel*eta*Tprime

*Evaluate integral over gtilde4 from 0 to infinity
integ `gtilde4' y, gen(`intg4') trapezoid

*Evaluate integral over gtilde4 from y to infinity
gen g4`suff' = r(integral) - `intg4'
label var g4`suff' "Term g4"


***Generate multiplier term (1-M_0)^{-1},
*** where M_0 = int_0^\infty etaterm(y') dy' + int_0^\infty nuterm(y') dy'   

*intensive-margin part is given by 'inteta' 
*Define term within integral: etaterm
gen `etaterm' = fykernel*eta*Tprime

*Evaluate integral over etaterm from 0 to infinity
integ `etaterm' y, trapezoid
local inteta = r(integral)

*extensive-margin part is given by 'intnu' 
*Define term within integral: nuterm
gen `nuterm' = fykernel*nu*TP

*Evaluate integral over nuterm from 0 to infinity
integ `nuterm' y, trapezoid
local intnu = r(integral)

*Compute value of multiplier (1-M_0)^{-1}
gen m`suff' = (1 - `inteta' - `intnu')^-1
label var m`suff' "Multiplier"

}

***Define g4 term and multiplier for cases without income effects
else {
gen m`suff' = 1
label var m`suff' "Multiplier"
gen g4`suff' = 0
label var g4`suff' "Term g4"
}


***Compute revenue function R

gen R`suff' = ( g1 - g2`suff' - g3`suff' - g4`suff' ) * m`suff'

*Define labels for benchmark (BM case) and different alternative cases 
if "`suf'" == "BM" {
label var R`suff' "Revenue function (BM)"
}

else if "`suf'" >= "11" & "`suf'" <= "13" {
label var R`suff' "Revenue function: epsi = `epsil'"
}

else if "`suf'" == "21"  {
label var R`suff' "Revenue function: pi = 0"
}

else if "`suf'" == "22"  {
label var R`suff' "Revenue function: pi in (`pil',`pih')"
}

else if "`suf'" == "31"  {
label var R`suff' "Revenue function: MPE =  -0.1"
}

else if "`suf'" == "32"  {
label var R`suff' "Revenue function: MPE =  -0.4"
}

else {
label var R`suff' "Revenue function"
}

***Drop elements of revenue function that are not further needed	
drop g1 g2`suff' g3`suff' g4`suff' m`suff'

end
